graphium.nn.architectures
====================

High level architectures in the library

=== "Contents"

    * [Global Architectures](#global-architectures)
    * [PyG Architectures](#pyg-architectures)
    * [Encoder Manager](#encoder-manager)


## Global Architectures
------------
::: graphium.nn.architectures.global_architectures


## PyG Architectures
------------
::: graphium.nn.architectures.pyg_architectures


## Encoder Manager
------------
::: graphium.nn.architectures.encoder_manager
